@@ -19,7 +19,8 @@ NMixChainsDerived <- function(object)
 {
   thispackage <- "mixAK"
 
-  if (!(class(object) %in% c("NMixMCMClist", "NMixMCMC"))) stop("object must be of class NMixMCMClist or NMixMCMC")
+  if (!(inherits(object, what = "NMixMCMClist") | inherits(object, what = "NMixMCMC"))) stop("object must be of class NMixMCMClist or NMixMCMC")
+  #if (!(class(object) %in% c("NMixMCMClist", "NMixMCMC"))) stop("object must be of class NMixMCMClist or NMixMCMC")
   
   ##### Quantiles and names of posterior summary statistics which are computed
   ##### for derived quantities
@@ -90,7 +91,7 @@ NMixChainsDerived <- function(object)
 
   
   ##### NMixMCMClist
-  if (class(object) == "NMixMCMClist"){
+  if (inherits(object, what = "NMixMCMClist")){
     if (object[[1]]$nx_w > 1) stop("This function has not (yet) been implemented if a factor covariate on mixture weights is present.")
     for (ch in 1:2){
       object[[ch]] <- NMixChDer(object[[ch]])      
@@ -100,7 +101,7 @@ NMixChainsDerived <- function(object)
 
 
   ##### NMixMCMC
-  if (class(object) == "NMixMCMC"){
+  if (inherits(object, what = "NMixMCMC")){
     if (object$nx_w > 1) stop("This function has not (yet) been implemented if a factor covariate on mixture weights is present.")      
     return(NMixChDer(object))
   }
