@@ -6,6 +6,7 @@
 //
 //  LOG:       20150414  created
 //             20220419  FCONE added where needed
+//             20240916  error --> Rf_error
 //
 // ======================================================================
 //
@@ -264,7 +265,7 @@ Deviance2(double* marg_ll,
                               ZS_i, sigma, q_ri, dist, R_c, R_d);       
 
     if (*err){ 
-      error("%s: TRAP (MCMC iteration %d), infinite log-likelihood for cluster %d of grouped obs.\n", fname, *iterNum, i + 1);
+      Rf_error("%s: TRAP (MCMC iteration %d), infinite log-likelihood for cluster %d of grouped obs.\n", fname, *iterNum, i + 1);
     }
 
 
@@ -328,7 +329,7 @@ Deviance2(double* marg_ll,
           break;
         default:
           *err = 1;
-          error("%s: Unimplemented distribution for random effects specified (place 1).\n", fname);    
+          Rf_error("%s: Unimplemented distribution for random effects specified (place 1).\n", fname);    
         }
         g_k0 += *cond_ll_iP;
 
@@ -375,7 +376,7 @@ Deviance2(double* marg_ll,
             /*** !!! dspsv destroys H_g !!!                                                ***/
             F77_CALL(dspsv)("L", dim_b, &AK_Basic::_ONE_INT, H_g, iwork, U_g, dim_b, err FCONE);
             if (*err){
-              //error("%s: TRAP (MCMC iteration %d): Singular Hessian encountered.\n", fname, *iterNum);    
+              //Rf_error("%s: TRAP (MCMC iteration %d): Singular Hessian encountered.\n", fname, *iterNum);    
               *err = 0;
 		AK_Basic::fillArray(U_g, 0.0, *dim_b);   
             }
@@ -385,7 +386,7 @@ Deviance2(double* marg_ll,
             break;
           default:
             *err = 1;
-            error("%s: Unimplemented distribution for random effects specified (place 2).\n", fname);    
+            Rf_error("%s: Unimplemented distribution for random effects specified (place 2).\n", fname);    
           }
 
           /*** Calculate the upper part of the new Z matrix (Zwork1_hat),                                      ***/
@@ -418,7 +419,7 @@ Deviance2(double* marg_ll,
               break;
             default:
               *err = 1;
-              error("%s: Unimplemented distribution for random effects specified (place 3).\n", fname);    
+              Rf_error("%s: Unimplemented distribution for random effects specified (place 3).\n", fname);    
             }
             g_k1 += cond_ll_hat;
             //if (i == clus_show && *iterNum == iter_show) Rprintf("\n%g",g_k1);
@@ -450,7 +451,7 @@ Deviance2(double* marg_ll,
                 break;
               default:
                 *err = 1;
-                error("%s: Unimplemented distribution for random effects specified (place 4).\n", fname);    
+                Rf_error("%s: Unimplemented distribution for random effects specified (place 4).\n", fname);    
               }
 
               MCMC::loglik_Zwork1_stres(&cond_ll_hat, b_hat_kP, Zwork1_hat, stres_hat, sqrt_w_phi_hat, eta_random_hat, meanY_hat, err, 
@@ -473,7 +474,7 @@ Deviance2(double* marg_ll,
                   break;
                 default:
                   *err = 1;
-                  error("%s: Unimplemented distribution for random effects specified (place 5).\n", fname);    
+                  Rf_error("%s: Unimplemented distribution for random effects specified (place 5).\n", fname);    
                 }
                 g_k1 += cond_ll_hat;
               }
@@ -548,7 +549,7 @@ Deviance2(double* marg_ll,
               /*** Cholesky decomposition of the minus Hessian ***/
               F77_CALL(dpptrf)("L", dim_b, I_glmm, err FCONE);   
               if (*err){
-                error("%s: TRAP (MCMC iteration %d), negative definite minus Hessian in the Laplace approximation (component %d) for cluster %d of grouped obs.\n", fname, *iterNum, i + 1, k + 1);
+                Rf_error("%s: TRAP (MCMC iteration %d), negative definite minus Hessian in the Laplace approximation (component %d) for cluster %d of grouped obs.\n", fname, *iterNum, i + 1, k + 1);
               }
 
               /*** Half times log-determinant of the minus Hessian ***/
@@ -556,7 +557,7 @@ Deviance2(double* marg_ll,
               break;
             default:
               *err = 1;
-              error("%s: Unimplemented distribution for random effects specified (place 6).\n", fname);    
+              Rf_error("%s: Unimplemented distribution for random effects specified (place 6).\n", fname);    
             }
             
             /*** Shift mixture mean (to have the code consistent with that in a part where we do not look for the model) ***/
@@ -723,7 +724,7 @@ Deviance2(double* marg_ll,
       case NMix::MVT:
       default:
         *err = 1;
-        error("%s: Unimplemented distribution for random effects specified (calculation of reff_L_i).\n", fname);
+        Rf_error("%s: Unimplemented distribution for random effects specified (calculation of reff_L_i).\n", fname);
       }      
 
     }                   // end of if (*dim_b)   (if there are random effects)
