@@ -17,6 +17,8 @@
 
 #include <R.h>
 #include <Rmath.h>
+#include <R_ext/Error.h>
+#include <R_ext/RS.h>
 
 #include "AK_Basic.h"
 #include "AK_BSTAT.h"
