@@ -25,6 +25,8 @@
 #include <R.h>
 #include <Rmath.h>
 #include <R_ext/Lapack.h>
+#include <R_ext/Error.h>
+#include <R_ext/RS.h>
 
 #include "AK_Basic.h"
 #include "AK_Utils.h"
